OC.L10N.register(
    "settings",
    {
    "Wrong password" : "رمز عبور اشتباه است",
    "No user supplied" : "هیچ کاربری تعریف نشده است",
    "Authentication error" : "خطا در اعتبار سنجی",
    "Wrong admin recovery password. Please check the password and try again." : "رمز مدیریتی بازیابی غلط است. لطفاً رمز را کنترل کرده و دوباره امتحان نمایید.",
    "Unable to change password" : "نمی‌توان رمز را تغییر داد",
    "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
    "Group already exists." : "گروه در حال حاضر موجود است",
    "Unable to add group." : "افزودن گروه امکان پذیر نیست.",
    "Unable to delete group." : "حذف گروه امکان پذیر نیست.",
    "Saved" : "ذخیره شد",
    "test email settings" : "تنظیمات ایمیل آزمایشی",
    "Email sent" : "ایمیل ارسال شد",
    "Invalid mail address" : "آدرس ایمیل نامعتبر است",
    "A user with that name already exists." : "کاربری با همین نام در حال حاضر وجود دارد.",
    "Unable to create user." : "ایجاد کاربر امکان‌پذیر نیست.",
    "Your %s account was created" : "حساب کاربری شما  %s ایجاد شد",
    "Unable to delete user." : "حذف کاربر امکان پذیر نیست.",
    "Forbidden" : "ممنوعه",
    "Invalid user" : "کاربر نامعتبر",
    "Unable to change mail address" : "تغییر آدرس ایمیل امکان‌پذیر نیست",
    "Your full name has been changed." : "نام کامل شما تغییر یافت",
    "Unable to change full name" : "امکان تغییر نام کامل وجود ندارد",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "__language_name__",
    "Language changed" : "زبان تغییر کرد",
    "Invalid request" : "درخواست نامعتبر",
    "Admins can't remove themself from the admin group" : "مدیران نمی توانند خود را از گروه مدیریت حذف کنند",
    "Unknown user" : "کاربر نامعلوم",
    "Couldn't remove app." : "امکان حذف برنامه وجود ندارد.",
    "Official" : "رسمی",
    "Approved" : "تایید شده",
    "All" : "همه",
    "Enabled" : "فعال شده",
    "Not enabled" : "غیر فعال",
    "No apps found for your version" : "هیچ برنامه‌ای برای نسخه‌ی شما یافت نشد",
    "Please wait...." : "لطفا صبر کنید ...",
    "Error while disabling app" : "خطا در هنگام غیر فعال سازی برنامه",
    "Disable" : "غیرفعال",
    "Enable" : "فعال",
    "Error while enabling app" : "خطا در هنگام فعال سازی برنامه",
    "Updating...." : "در حال بروز رسانی...",
    "Error while updating app" : "خطا در هنگام بهنگام سازی برنامه",
    "Updated" : "بروز رسانی انجام شد",
    "Uninstalling ...." : "در حال حذف...",
    "Error while uninstalling app" : "خطا در هنگام حذف برنامه....",
    "Uninstall" : "حذف",
    "App update" : "به روز رسانی برنامه",
    "Experimental" : "آزمایشی",
    "Add trusted domain" : "افزودن دامنه مورد اعتماد",
    "Migration in progress. Please wait until the migration is finished" : "مهاجرت در حال اجراست. لطفا تا اتمام مهاجرت صبر کنید",
    "Migration started …" : "مهاجرت شروع شد...",
    "Valid until {date}" : "معتبر تا {date}",
    "Delete" : "حذف",
    "Sending..." : "در حال ارسال...",
    "An error occurred: {message}" : "یک خطا رخ‌داده است: {message}",
    "Select a profile picture" : "انتخاب تصویر پروفایل",
    "Very weak password" : "رمز عبور بسیار ضعیف",
    "Weak password" : "رمز عبور ضعیف",
    "So-so password" : "رمز عبور متوسط",
    "Good password" : "رمز عبور خوب",
    "Strong password" : "رمز عبور قوی",
    "Groups" : "گروه ها",
    "Unable to delete {objName}" : "امکان حذف {objName} وجود ندارد",
    "A valid group name must be provided" : "نام کاربری معتبر می بایست وارد شود",
    "deleted {groupName}" : "گروه {groupName} حذف شد",
    "undo" : "بازگشت",
    "never" : "هرگز",
    "deleted {userName}" : "کاربر {userName} حذف شد",
    "add group" : "افزودن گروه",
    "enabled" : "فعال شده",
    "disabled" : "غیر فعال شده",
    "no group" : "هیچ گروهی",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "با توجه به عدم دستیابی به بازگردانی اطلاعات برای کاربر، تغییر رمز عبور باعث از بین رفتن اطلاعات خواهد شد",
    "A valid username must be provided" : "نام کاربری صحیح باید وارد شود",
    "A valid password must be provided" : "رمز عبور صحیح باید وارد شود",
    "A valid email must be provided" : "یک ایمیل معتبر باید وارد شود",
    "Cheers!" : "سلامتی!",
    "User documentation" : "مستندات کاربر",
    "Administrator documentation" : "مستندات مدیر",
    "Online documentation" : "مستندات آنلاین",
    "Forum" : "انجمن",
    "Commercial support" : "پشتیبانی تجاری",
    "Developer documentation" : "مستندات توسعه‌دهندگان",
    "Documentation:" : "مستند سازی:",
    "Admin documentation" : "مستندات مدیر",
    "Show description …" : "نمایش توضیحات ...",
    "Hide description …" : "عدم نمایش توضیحات...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "امکان نصب این برنامه وجود ندارد، این پیش‌نیازها انجام نشده‌اند:",
    "Enable only for specific groups" : "فعال سازی تنها برای گروه های خاص",
    "Uninstall App" : "حذف برنامه",
    "Cron" : "زمانبند",
    "Cron was not executed yet!" : "کران هنوز اجرا نشده است!",
    "Open documentation" : "بازکردن مستند",
    "Execute one task with each page loaded" : "اجرای یک وظیفه با هر بار بارگذاری صفحه",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php در یک سرویس webcron ثبت شده است که هر 15 دقیقه یک بار بر روی بستر http فراخوانی شود.",
    "Common Name" : "نام مشترک",
    "Valid until" : "متعبر تا",
    "Issued By" : "صدور توسط",
    "Valid until %s" : "متعبر تا %s",
    "Import root certificate" : "وارد کردن گواهی اصلی",
    "Server-side encryption" : "رمزگذاری سمت سرور",
    "Enable server-side encryption" : "فعال‌سازی رمزگذاری سمت-سرور",
    "Be aware that encryption always increases the file size." : "توجه داشته باشید که همواره رمزگذاری حجم فایل را افزایش خواهد داد.",
    "This is the final warning: Do you really want to enable encryption?" : "این آخرین اخطار است: آیا می‌خواهید رمزگذاری را فعال کنید ؟",
    "Enable encryption" : "فعال کردن رمزگذاری",
    "No encryption module loaded, please enable an encryption module in the app menu." : "هیچ ماژول رمزگذاری‌ای بارگذاری نشده است، لطفا ماژول رمز‌گذاری را در منو برنامه فعال کنید.",
    "Select default encryption module:" : "انتخاب ماژول پیش‌فرض رمزگذاری:",
    "Start migration" : "شروع مهاجرت",
    "Sharing" : "اشتراک گذاری",
    "Allow apps to use the Share API" : "اجازه ی برنامه ها برای استفاده از API اشتراک گذاری",
    "Allow users to share via link" : "اجازه دادن به کاربران برای اشتراک گذاری توسط پیوند",
    "Allow public uploads" : "اجازه بارگذاری عمومی",
    "Enforce password protection" : "اجبار برای محافظت توسط رمز عبور",
    "Set default expiration date" : "اعمال تاریخ اتمام پیش فرض",
    "Allow users to send mail notification for shared files" : "اجازه به کاربران برای ارسال ایمیل نوتیفیکیشن برای فایل‌های به اشتراک‌گذاشته شده",
    "Expire after " : "اتمام اعتبار بعد از",
    "days" : "روز",
    "Enforce expiration date" : "اعمال تاریخ اتمام اشتراک گذاری",
    "Allow resharing" : "مجوز اشتراک گذاری مجدد",
    "Restrict users to only share with users in their groups" : "محدود کردن کاربران برای اشتراک‌گذاری تنها میان کاربران گروه خود",
    "Exclude groups from sharing" : "مستثنی شدن گروه ها از اشتراک گذاری",
    "Everything (fatal issues, errors, warnings, info, debug)" : "همه موارد (مشکلات مهلک، خطاها، اخطارها، اطلاعات، خطایابی)",
    "Info, warnings, errors and fatal issues" : "اطلاعات، اخطارها، خطاها، مشکلات اساسی",
    "Warnings, errors and fatal issues" : "اخطارها، خطاها، مشکلات مهلک",
    "Errors and fatal issues" : "خطاها و مشکلات اساسی",
    "Fatal issues only" : "فقط مشکلات اساسی",
    "Log" : "کارنامه",
    "None" : "هیچ‌کدام",
    "Login" : "ورود",
    "Plain" : "ساده",
    "NT LAN Manager" : "مدیر NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "سرور ایمیل",
    "This is used for sending out notifications." : "این برای ارسال هشدار ها استفاده می شود",
    "Send mode" : "حالت ارسال",
    "Encryption" : "رمزگذاری",
    "From address" : "آدرس فرستنده",
    "mail" : "ایمیل",
    "Authentication method" : "روش احراز هویت",
    "Authentication required" : "احراز هویت مورد نیاز است",
    "Server address" : "آدرس سرور",
    "Port" : "درگاه",
    "Credentials" : "اعتبارهای",
    "SMTP Username" : "نام کاربری SMTP",
    "SMTP Password" : "رمز عبور SMTP",
    "Test email settings" : "تنظیمات ایمیل آزمایشی",
    "Send email" : "ارسال ایمیل",
    "Security & setup warnings" : "اخطارهای نصب و امنیتی",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "ماژول 'fileinfo' PHP از کار افتاده است.ما اکیدا توصیه می کنیم که این ماژول را فعال کنید تا نتایج بهتری به وسیله ی mime-type detection دریافت کنید.",
    "All checks passed." : "تمامی موارد با موفقیت چک شدند.",
    "Tips & tricks" : "نکات و راهنمایی‌ها",
    "Advanced monitoring" : "مانیتورینگ پیشرفته",
    "Performance tuning" : "تنظیم کارایی",
    "Improving the config.php" : "بهبود config.php",
    "Theming" : "قالب‌بندی",
    "Hardening and security guidance" : "راهنمای امن‌سازی",
    "Get the apps to sync your files" : "برنامه ها را دریافت کنید تا فایل هایتان را همگام سازید",
    "Desktop client" : "نرم افزار دسکتاپ",
    "Android app" : "اپ اندروید",
    "iOS app" : "اپ iOS",
    "Show First Run Wizard again" : "راهبری کمکی اجرای اول را دوباره نمایش بده",
    "Profile picture" : "تصویر پروفایل",
    "Upload new" : "بارگذاری جدید",
    "Remove image" : "تصویر پاک شود",
    "Cancel" : "منصرف شدن",
    "Full name" : "نام کامل",
    "No display name set" : "هیچ نام نمایشی تعیین نشده است",
    "Email" : "ایمیل",
    "Your email address" : "پست الکترونیکی شما",
    "No email address set" : "آدرس‌ایمیلی تنظیم نشده است",
    "You are member of the following groups:" : "شما عضو این گروه‌ها هستید:",
    "Password" : "گذرواژه",
    "Unable to change your password" : "ناتوان در تغییر گذرواژه",
    "Current password" : "گذرواژه کنونی",
    "New password" : "گذرواژه جدید",
    "Change password" : "تغییر گذر واژه",
    "Language" : "زبان",
    "Help translate" : "به ترجمه آن کمک کنید",
    "Unlimited" : "نامحدود",
    "Name" : "نام",
    "Username" : "نام کاربری",
    "Version" : "نسخه",
    "Personal" : "شخصی",
    "Admin" : "مدیر",
    "Error" : "خطا",
    "Show storage location" : "نمایش محل ذخیره‌سازی",
    "Show last log in" : "نمایش اخرین ورود",
    "Send email to new user" : "ارسال ایمیل به کاربر جدید",
    "Show email address" : "نمایش پست الکترونیکی",
    "E-Mail" : "ایمیل",
    "Create" : "ایجاد کردن",
    "Admin Recovery Password" : "مدیریت بازیابی رمز عبور",
    "Enter the recovery password in order to recover the users files during password change" : "در حین تغییر رمز عبور به منظور بازیابی فایل های کاربران، رمز عبور بازیابی را وارد کنید",
    "Add Group" : "افزودن گروه",
    "Group" : "گروه",
    "Everyone" : "همه",
    "Admins" : "مدیران",
    "Default Quota" : "سهم پیش فرض",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "لطفا سهمیه ذخیره سازی را وارد کنید (به عنوان مثال: \" 512MB\" یا \"12GB\")",
    "Other" : "دیگر",
    "Full Name" : "نام کامل",
    "Group Admin for" : "مدیر گروه برای",
    "Quota" : "سهم",
    "Storage Location" : "محل فضای ذخیره سازی",
    "Last Login" : "اخرین ورود",
    "change full name" : "تغییر نام کامل",
    "set new password" : "تنظیم کلمه عبور جدید",
    "change email address" : "تغییر آدرس ایمیل ",
    "Default" : "پیش فرض",
    "The new password can not be the same as the previous one" : "رمز عبور جدید نمی تواند مانند قبلی باشد",
    "Change" : "تغییر",
    "Share" : "اشتراک گذاری",
    "The app will be downloaded from the app store" : "برنامه از app store دانلود خواهد شد",
    "Disconnect" : "قطع",
    "installing and updating apps via the market or Federated Cloud Sharing" : "نصب و به روز رسانی برنامه از طریق بازار یا Federated Cloud Sharing",
    "Domain" : "دامنه",
    "Add" : "افزودن",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "خطایی در ارسال ایمیل رخ داده است. لطفا تنظیمات خود را اصلاح کنید. (خطا: %s)",
    "Error: this app cannot be enabled because it makes the server unstable" : "خطا: برنامه فعال نمی شود زیرا سرور را ناپایدار می نماید",
    "Error: could not disable broken app" : "خطا: برنامه از کار افتاده غیرفعال نمی شود",
    "Error while disabling broken app" : "خظا در غیر فعال سازی برنامه از کار افتاده",
    "CORS" : "CORS",
    "log-level out of allowed range" : "log-level خارج از محدوده مجاز است",
    "Error while loading browser sessions and device tokens" : "خطا در هنگام بارگذاری جلسات مرورگر و نشانه های دستگاه",
    "Error while creating device token" : "خطا در ساخت نشانه دستگاه",
    "Error while deleting the token" : "خطا در حذف نشانه",
    "%s password changed successfully" : "%s رمز عبور با موفقیت تغییر کرد",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "برنامه های رسمی توسط و درون جامعه ownCloud توسعه می یابند. آن ها قابلیت های مرکزی خود را برای ownCloud ارائه می دهند و آماده استفاده برای تولید هستند.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "برنامه های تأیید شده توسط توسعه دهندگان معتبر توسعه داده شده اند و از یک بررسی امنیتی مدرن عبور کرده اند. آنها به طور فعال در یک مخزن کد باز نگهداری می شوند و نگه دارندگان معتقدند که  آن ها برای استفاده اتفاقی تا عادی پایدار هستند.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "این برنامه از نظر امنیت بررسی نشده است و جدید بوده یا ناپایدار به نظر می رسد. با مسئولیت خودتان نصب نمایید.",
    "No apps found for {query}" : "هیچ برنامه ای برای {query} یافت نشد",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL از یک %sنسخه (%s) منسوخ شده استفاده می کند. لطفا سیستم عامل خود را به روز رسانی کنید یا ویژگی‌هایی مانند %s به درستی کار نخواهند کرد.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "برنامه فعال شده است اما لازم است به روز رسانی شود. شما پس از 5 ثانیه به صفحه به روز رسانی برگردانده خواهید شد.",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "خطایی اتفاق افتاده است. لطفا یک تایید ASCII-encoded PEM بارگذاری نمایید.",
    "Empty app name is not allowed." : "نام برنامه نمی تواند خالی باشد.",
    "You need to set your user email before being able to send test emails." : "شما باید ایمیل کاربری خود را قبل از امکان ارسال ایمیل آزمایشی تنظیم نمایید.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "به ویژه هنگام استفاده از مشتری دسکتاپ برای همگام سازی پرونده، استفاده از SQLite دلسرد کننده است.",
    "Email has been changed successfully." : "ایمیل با موفقیت تغییر کرد."
},
"nplurals=1; plural=0;");
